@@ -1,11 +1,12 @@
 # Copyright (C) 2002, Thomas Hamelryck (thamelry@binf.ku.dk)
-# This code is part of the Biopython distribution and governed by its
-# license.  Please see the LICENSE file that should have been included
-# as part of this package.
+#
+# This file is part of the Biopython distribution and governed by your
+# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
+# Please see the LICENSE file that should have been included as part of this
+# package.
 
 """Turn an mmCIF file into a dictionary."""
 
-from __future__ import print_function
 
 from Bio.File import as_handle
 
@@ -20,13 +21,16 @@ class MMCIF2Dict(dict):
          - file - name of the PDB file OR an open filehandle
 
         """
-        self.quote_chars = ['\'', '\"']
-        self.whitespace_chars = [' ', '\t']
+        self.quote_chars = ["'", '"']
+        self.whitespace_chars = [" ", "\t"]
         with as_handle(filename) as handle:
             loop_flag = False
             key = None
             tokens = self._tokenize(handle)
-            token = next(tokens)
+            try:
+                token = next(tokens)
+            except StopIteration:
+                return  # for Python 3.7 and PEP 479
             self[token[0:5]] = token[5:]
             i = 0
             n = 0
@@ -57,7 +61,7 @@ class MMCIF2Dict(dict):
                 if key is None:
                     key = token
                 else:
-                    self[key] = token
+                    self[key] = [token]
                     key = None
 
     # Private methods
@@ -74,13 +78,13 @@ class MMCIF2Dict(dict):
                     in_token = False
                     yield line[start_i:i]
             elif c in self.quote_chars:
-                if not quote_open_char:
-                    if in_token:
-                        raise ValueError("Opening quote in middle of word: " + line)
+                if not quote_open_char and not in_token:
                     quote_open_char = c
                     in_token = True
                     start_i = i + 1
-                elif c == quote_open_char and (i + 1 == len(line) or line[i + 1] in self.whitespace_chars):
+                elif c == quote_open_char and (
+                    i + 1 == len(line) or line[i + 1] in self.whitespace_chars
+                ):
                     quote_open_char = None
                     in_token = False
                     yield line[start_i:i]
@@ -98,7 +102,9 @@ class MMCIF2Dict(dict):
             raise ValueError("Line ended with quote open: " + line)
 
     def _tokenize(self, handle):
+        empty = True
         for line in handle:
+            empty = False
             if line.startswith("#"):
                 continue
             elif line.startswith(";"):
@@ -108,10 +114,15 @@ class MMCIF2Dict(dict):
                 token_buffer = [line[1:].rstrip()]
                 for line in handle:
                     line = line.rstrip()
-                    if line == ';':
+                    if line.startswith(";"):
+                        yield "\n".join(token_buffer)
+                        line = line[1:]
+                        if line and not line[0] in self.whitespace_chars:
+                            raise ValueError("Missing whitespace")
                         break
                     token_buffer.append(line)
-                yield "\n".join(token_buffer)
-            else:
-                for token in self._splitline(line.strip()):
-                    yield token
+                else:
+                    raise ValueError("Missing closing semicolon")
+            yield from self._splitline(line.strip())
+        if empty:
+            raise ValueError("Empty file.")
