@@ -68,14 +68,14 @@ is a named tuple consisting of the two aligned sequences, the score and the
 start and end positions of the alignment:
 
    >>> print(alignments)
-   [Alignment(seqA='ACCGT', seqB='A-CG-', score=3, start=0, end=5), ...
+   [Alignment(seqA='ACCGT', seqB='A-CG-', score=3.0, start=0, end=5), ...
 
-You can access each element of an aligment by index or name:
+You can access each element of an alignment by index or name:
 
    >>> alignments[0][2]
-   3
+   3.0
    >>> alignments[0].score
-   3
+   3.0
 
 For a nice printout of an alignment, use the ``format_alignment`` method of
 the module:
@@ -232,10 +232,10 @@ Some examples:
     <BLANKLINE>
 
 - The alignment function can also use known matrices already included in
-  Biopython (``MatrixInfo`` from ``Bio.SubsMat``):
+  Biopython (in ``Bio.Align.substitution_matrices``):
 
-    >>> from Bio.SubsMat import MatrixInfo as matlist
-    >>> matrix = matlist.blosum62
+    >>> from Bio.Align import substitution_matrices
+    >>> matrix = substitution_matrices.load("BLOSUM62")
     >>> for a in pairwise2.align.globaldx("KEVLA", "EVL", matrix):
     ...     print(format_alignment(*a))
     KEVLA
@@ -662,13 +662,13 @@ def _make_score_matrix_generic(
         if penalize_end_gaps[1]:  # [1]:gap in sequence B
             score = gap_B_fn(0, i)
         else:
-            score = 0
+            score = 0.0
         score_matrix[i][0] = score
     for i in range(lenB + 1):
         if penalize_end_gaps[0]:  # [0]:gap in sequence A
             score = gap_A_fn(0, i)
         else:
-            score = 0
+            score = 0.0
         score_matrix[0][i] = score
 
     # Fill in the score matrix.  Each position in the matrix
@@ -717,7 +717,7 @@ def _make_score_matrix_generic(
             best_score = max(nogap_score, row_open, row_extend, col_open, col_extend)
             local_max_score = max(local_max_score, best_score)
             if not align_globally and best_score < 0:
-                score_matrix[row][col] = 0
+                score_matrix[row][col] = 0.0
             else:
                 score_matrix[row][col] = best_score
 
@@ -973,7 +973,7 @@ def _recover_alignments(
         # and stop the backtrace (dead_end) if a gap in seqB follows.
         #
         # Attention: This may fail, if the gap-penalties for both strands are
-        # different. In this case the second aligment may be the only optimal
+        # different. In this case the second alignment may be the only optimal
         # alignment. Thus it can happen that no alignment is returned. For
         # this case a workaround was implemented, which reverses the input and
         # the matrices (this happens in _reverse_matrices) and repeats the
@@ -985,7 +985,7 @@ def _recover_alignments(
             cache = (ali_seqA[:], ali_seqB[:], end, row, col, col_gap)
 
             # If trace is empty we have reached at least one border of the
-            # matrix or the end of a local aligment. Just add the rest of
+            # matrix or the end of a local alignment. Just add the rest of
             # the sequence(s) and fill with gaps if necessary.
             if not trace:
                 if col and col_gap:
@@ -1313,7 +1313,7 @@ class affine_penalty:
 def calc_affine_penalty(length, open, extend, penalize_extend_when_opening):
     """Calculate a penality score for the gap function."""
     if length <= 0:
-        return 0
+        return 0.0
     penalty = open + extend * length
     if not penalize_extend_when_opening:
         penalty -= extend
